Several auxilliary functions for Petri Net objects.
n_places(PN)n_transitions(PN)
n_flows(PN)
n_nodes(PN)
rename_transitions(PN, .f, ...)
rename_places(PN, .f, ...)
add_places(PN, places)
add_transitions(PN, transitions)
add_flows(PN, flows)
A petri net
A function name to apply for renaming
Additional arguments
data.frame or tibble of places, with columns id and label. Both columns should be characters.
data.frame or tibble of transitions, with columns id and label. Both columns should be characters.
data.frame or tibble of flows, with columns named "from" and "to", referring to ids of places and transitions. Both columns should be characters.